@@ -1,7 +1,7 @@
 package Plack::Response;
 use strict;
 use warnings;
-our $VERSION = '1.0019';
+our $VERSION = '1.0025';
 $VERSION = eval $VERSION;
 
 use Plack::Util::Accessor qw(body status);
@@ -108,6 +108,12 @@ sub finalize {
     ];
 }
 
+sub to_app {
+    my $self = shift;
+    return sub { $self->finalize };
+}
+
+
 sub _body {
     my $self = shift;
     my $body = $self->body;
@@ -296,6 +302,13 @@ B<does not> convert string formats such as C<+3M>.
 Returns the status code, headers, and body of this response as a PSGI
 response array reference.
 
+=item to_app
+
+  $app = $res->to_app;
+
+A helper shortcut for C<< sub { $res->finalize } >>.
+
+
 =back
 
 =head1 AUTHOR
